pub fn extract(file: &ParsedFile) -> Option<Capability>Expand description
Extract services from Python classes ending in Service, or decorated with @inject, or module-level functions in files with service/crud/repository in the path.
pub fn extract(file: &ParsedFile) -> Option<Capability>Extract services from Python classes ending in Service, or decorated with @inject, or module-level functions in files with service/crud/repository in the path.