pub fn analyze_project(path: &Path) -> Result<ProjectSpec, PythonAnalysisError>Expand description
Analyze a Python project directory and extract behavior specs.
pub fn analyze_project(path: &Path) -> Result<ProjectSpec, PythonAnalysisError>Analyze a Python project directory and extract behavior specs.